==> fusenshi-0.7.5.tgz: fusenshi-0.7.5/src/include/commandcontrol.h <==
/*
 * $Id: commandcontrol.h,v 1.2 2005/01/28 09:01:58 ozawa Exp $
 *
 * Copyright 2003- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.2 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 *
 */

#ifndef ___COMMANDCONTROL_H
#define ___COMMANDCONTROL_H

#include "glib.h"
#include "../include/commandid.h"

/**
 * ץ֤륳ޥɤ˴
 * ưޤ
 */
class CommandControl {
public:
    /**
     * 󥹥ȥ饯
     */
    CommandControl();
    
    /**
     * ǥȥ饯
     */
    ~CommandControl();
    
    /**
     * ޥɤ򥭥塼ɲäޤ
     * 
     * @param nCommandID ޥID
     * @param nFileID оݤΥեID
     * @param pData ޥɤ˸ͭΥǡ
     */
    void addCommand(guint nCommandID, guint nFileID, gpointer pData);
    
    /**
     * ޥɤ˴ޤ
     * 
     * @param lpCommand ޥ
     */
    void destroyCommand(LP_COMMAND lpCommand);
    
    /**
     * ƬΥޥɤ򣱤ĥ塼Фޤ
     * 
     * @return ޥ
     */
    LP_COMMAND getCommand();
    
    /**
     * ޥɤޤ
     * 
     * @param nIn ѥǥץ
     * @return ޥɡޥɤǤʤ NULL
     */
    LP_COMMAND receiveCommand(int nIn);
    
    /**
     * ޥɤޤ
     * 
     * @param nOut ѥǥץ
     * @param lpCommand ޥ
     */
    void sendCommand(int nOut, const LP_COMMAND lpCommand);
    
    /**
     * ޥɤӡޥɤȯޤԵޤ
     * 
     * @param nIn ѥǥץ
     * @param utime Ե֤ޥñ̤ǻꤷޤ
     *              ꤹȥޥɤȯޤԵޤ
     * @return ޥɤȯ true ᤷޤ
     */
    bool wait(int nIn, unsigned long utime);
    
private:
    /**
     * ޥɥ塼
     */
    GQueue* m_pCommands;
    
    /**
     * Ʊѥߥ塼ƥå
     */
    GMutex* m_pMutex;
};

#endif

==> fusenshi-0.8.2.tgz: fusenshi-0.8.2/src/include/commandcontrol.h <==
/*
 * $Id: commandcontrol.h,v 1.4 2005/11/24 14:21:03 ozawa Exp $
 *
 * Copyright 2003- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.4 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 *
 */

#ifndef ___COMMANDCONTROL_H
#define ___COMMANDCONTROL_H

#include "glib.h"
#include "../include/commandid.h"

/**
 * ץ֤륳ޥɤ˴
 * ưޤ
 */
class CommandControl {
public:
    /**
     * 󥹥ȥ饯
     */
    CommandControl();
    
    /**
     * ǥȥ饯
     */
    ~CommandControl();
    
    /**
     * ޥɤ򥭥塼ɲäޤ
     * 
     * @param nCommandID ޥID
     * @param nFileID оݤΥեID
     * @param pData ޥɤ˸ͭΥǡ
     */
    void addCommand(u_int32_t nCommandID, u_int32_t nFileID,
                    u_int32_t nExtraFlag, u_int32_t nDataLen, void *pData);
    
    /**
     * ޥɤ˴ޤ
     * 
     * @param lpCommand ޥ
     */
    void destroyCommand(LP_COMMAND lpCommand);
    
    /**
     * ƬΥޥɤ򣱤ĥ塼Фޤ
     * 
     * @return ޥ
     */
    LP_COMMAND getCommand();
    
    /**
     * ޥɤޤ
     * 
     * @param nIn ѥǥץ
     * @return ޥɡޥɤǤʤ NULL
     */
    LP_COMMAND receiveCommand(int nIn);
    
    /**
     * ޥɤޤ
     * 
     * @param nOut ѥǥץ
     * @param lpCommand ޥ
     */
    void sendCommand(int nOut, const LP_COMMAND lpCommand);
    
    /**
     * ޥɤӡޥɤȯޤԵޤ
     * 
     * @param nIn ѥǥץ
     * @param utime Ե֤ޥñ̤ǻꤷޤ
     *              ꤹȥޥɤȯޤԵޤ
     * @return ޥɤȯ true ᤷޤ
     */
    bool wait(int nIn, unsigned long utime);
    
private:
    /**
     * ޥɥ塼
     */
    GQueue* m_pCommands;
    
    /**
     * Ʊѥߥ塼ƥå
     */
    GMutex* m_pMutex;
};

#endif
